@@ -39,6 +39,7 @@ from awscli.customizations.route53resourceid import register_resource_id
 from awscli.customizations.configure import register_configure_cmd
 from awscli.customizations.cloudtrail import initialize as cloudtrail_init
 from awscli.customizations.toplevelbool import register_bool_params
+from awscli.customizations.ec2protocolarg import register_protocol_args
 
 
 def awscli_initialize(event_handlers):
@@ -81,3 +82,4 @@ def awscli_initialize(event_handlers):
     register_configure_cmd(event_handlers)
     cloudtrail_init(event_handlers)
     register_bool_params(event_handlers)
+    register_protocol_args(event_handlers)
