@@ -14,9 +14,11 @@
 
 import logging
 import os
-import requests
+
+from botocore.vendored import requests
 import six
 
+
 logger = logging.getLogger(__name__)
 
 
